searchNodes=[{"doc":"The main module you'll interact with. This module provides two functions, generate/1 and test/1 , where the former essentially depends on the latter. That is, generate/1 generates a prime by means of yielding a random number using Enum.random/1 and, if the number gained is proven by test/1 to be a prime, it returns the prime, and if not it recursively invokes generate/1 until Enum.random/1 successfully returns a prime. Prime number theorem asserts that the distribution of the number of prime numbers between 1 and n is approximately n/ln(n) . Therefore we can assume the probability for the randomly chosen number between 1 and n to be the prime number is 1/ln(n) . ln(2^128) approximately equals to 89. This means you only need less than 100 attempts to find a prime number between 1 and 2^128. That's why it's just ok to make a loop. Note, however, that the probablistic nature again reside in the test/1 , hence there is actually a little more than 1/ln(n) steps to generate a prime. See the doc of Prime.Fermat.test/1 for details.","ref":"Prime.html","title":"Prime","type":"module"},{"doc":"Returns a random prime number of given bit size.","ref":"Prime.html#generate/1","title":"Prime.generate/1","type":"function"},{"doc":"Tests if the given number is a prime. Examples iex&gt; Prime . test ( 3 ) true iex&gt; Prime . test ( 42 ) false iex&gt; Prime . test ( 561 ) false iex&gt; Prime . test ( 1_000_000_007 ) true","ref":"Prime.html#test/1","title":"Prime.test/1","type":"function"},{"doc":"Implementation of Fermat-test. This module provides the primality test based on Fermat's Little Theorem. The methodology is essentially probablistic, which means even if the result says the number given is a prime, there is no strong guarantee that it actually is. It only tells the chance is good it is. In practice, the more times you give it a try, the more probable the number is a prime. Also, there is a series of contrary evidences with which Fermat test is known to fail. The sequence is known as Carmichael numbers, and they are infinite. Despite the deficiency, Fermat test is largely entrusted, widely employed algorithm for larger primes, partly because Carmichael numbers are not very abundant (there are 255 of them below 10^8 ) and they get even rarer as number gets bigger. Abelson and Sussman in SICP put it that the risk of gaining false positive is &quot;less than the chance that cosmic radiation will cause the computer to cause an error&quot;. With all of that said, Prime.MillerRabin implements another famous algorithm which overcomes the pitfall. This module is only expected to be utilized for learning purpose, otherwise go look at Prime.MillerRabin .","ref":"Prime.Fermat.html","title":"Prime.Fermat","type":"module"},{"doc":"Returns the result of fermat-test. Examples iex&gt; Prime.Fermat . test ( 1 ) false iex&gt; Prime.Fermat . test ( 2 ) true iex&gt; Prime.Fermat . test ( 3 ) true iex&gt; Prime.Fermat . test ( 42 ) false iex&gt; Prime.Fermat . test ( 561 ) true # false positive: the first carmichael number.","ref":"Prime.Fermat.html#test/1","title":"Prime.Fermat.test/1","type":"function"},{"doc":"Implementation of Miller-Rabin-test. This module provides the primality test based on Miller-Rabin's method. The methodology is essentially probablistic. See the doc of Prime.Fermat for details. The unignorable difference between fermat-test and miller-rabin-test is that the latter defeats Carmichael numbers while giving up no efficiency. You might feel easier to reason towards employing this algorithm than the fermat-test, although they are equally great formulations of the intrinsic nature of numbers.","ref":"Prime.MillerRabin.html","title":"Prime.MillerRabin","type":"module"},{"doc":"Returns the result of miller-rabin-test. Examples iex&gt; Prime.MillerRabin . test ( 1 ) false iex&gt; Prime.MillerRabin . test ( 2 ) true iex&gt; Prime.MillerRabin . test ( 3 ) true iex&gt; Prime.MillerRabin . test ( 42 ) false iex&gt; Prime.MillerRabin . test ( 561 ) false # won&#39;t get fooled by the first carmichael number.","ref":"Prime.MillerRabin.html#test/1","title":"Prime.MillerRabin.test/1","type":"function"}]